﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Input;

using WpfModelViewApplication1.Commands;
using WpfModelViewApplication1.Models;
using System.Collections.ObjectModel;
using System.ComponentModel;

namespace WpfModelViewApplication1.ViewModels
{
    public class MainViewModel : ViewModelBase
    {
        private DelegateCommand exitCommand;
        private DelegateCommand setAllowEdit;
        private DelegateCommand setAllowAddNew;
        private DelegateCommand setAllowRecordFiltering;

        private bool allowAddNew;
        private bool allowEdit;
        private bool allowRecordFiltering;
        private BindingList<Person> people;

        public BindingList<Person> People
        {
            get { return people; }
        }
        public bool AllowAddNew
        {
            get { return allowAddNew; }
            set 
            {
                allowAddNew = value;
                OnPropertyChanged("AllowAddNew");
            }
        }
        public bool AllowEdit
        {
            get { return allowEdit; }
            set 
            {
                allowEdit = value;
                OnPropertyChanged("AllowEdit");
            }
        }
        public bool AllowRecordFiltering
        {
            get { return allowRecordFiltering; }
            set
            {
                allowRecordFiltering = value;
                OnPropertyChanged("AllowRecordFiltering");
            }
        }

        #region Constructor

        public MainViewModel()
        {
            //this.allowAddNew = false;
            //this.allowEdit = false;
            //this.allowRecordFiltering = false;

            this.allowAddNew = true;
            this.allowEdit = true;
            this.allowRecordFiltering = true;

            people = new BindingList<Person>()
            {
                new Person(){ FirstName="FN1", LastName="LN1", Age=1},
                new Person(){ FirstName="FN2", LastName="LN2", Age=2},
                new Person(){ FirstName="FN3", LastName="LN3", Age=3},
                new Person(){ FirstName="FN4", LastName="LN4", Age=4}
            };
        }

        #endregion

        public ICommand ExitCommand
        {
            get
            {
                if (exitCommand == null)
                {
                    exitCommand = new DelegateCommand(Exit);
                }
                return exitCommand;
            }
        }
        public ICommand SetAllowEdit
        {
            get
            {
                if (setAllowEdit == null)
                {
                    setAllowEdit = new DelegateCommand(AllowEditHandler);
                }
                return setAllowEdit;
            }
        }
        public ICommand SetAllowAddNew
        {
            get
            {
                if (setAllowAddNew == null)
                {
                    setAllowAddNew = new DelegateCommand(AllowAddNewHandler);
                }
                return setAllowAddNew;
            }
        }
        public ICommand SetAllowRecordFiltering
        {
            get
            {
                if (setAllowRecordFiltering == null)
                {
                    setAllowRecordFiltering = new DelegateCommand(AllowRecordFilteringHandler);
                }
                return setAllowRecordFiltering;
            }
        }

        private void Exit()
        {
            Application.Current.Shutdown();
        }
        private void AllowEditHandler()
        {
            this.allowEdit = false;
        }
        private void AllowAddNewHandler()
        {
            this.allowAddNew = false;
        }
        private void AllowRecordFilteringHandler()
        {
            this.allowRecordFiltering = false;
        }
    }
}
